==> knative-client-4.13.0-sources.jar: io/fabric8/knative/client/eventing/v1/internal/BrokerOperationsImpl.java <==


                        
      
package io.fabric8.knative.client.eventing.v1.internal;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;

import okhttp3.OkHttpClient;

import io.fabric8.knative.eventing.v1.DoneableBroker;
import io.fabric8.knative.eventing.v1.Broker;
import io.fabric8.knative.eventing.v1.BrokerList;
import io.fabric8.knative.eventing.v1.DoneableBroker;

import java.util.Map;
import java.util.TreeMap;


public class BrokerOperationsImpl extends HasMetadataOperation<Broker, BrokerList, DoneableBroker, Resource<Broker, DoneableBroker>> {

  public BrokerOperationsImpl(OkHttpClient client, Config config) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public BrokerOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("eventing.knative.dev")
    .withApiGroupVersion("v1")
    .withPlural("brokers"));
    this.type = Broker.class;
    this.listType = BrokerList.class;
    this.doneableType = DoneableBroker.class;
  }

  public BrokerOperationsImpl newInstance(OperationContext context) {
    return new BrokerOperationsImpl(context);
  }

  @Override
  public boolean isResourceNamespaced() {
    return true;
  }
}

==> knative-client-5.6.0-sources.jar: io/fabric8/knative/client/eventing/v1/internal/BrokerOperationsImpl.java <==


                        
      
package io.fabric8.knative.client.eventing.v1.internal;

import io.fabric8.kubernetes.api.builder.Visitor;
import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;

import okhttp3.OkHttpClient;

import io.fabric8.knative.eventing.v1.Broker;
import io.fabric8.knative.eventing.v1.BrokerBuilder;
import io.fabric8.knative.eventing.v1.BrokerList;

import java.util.Map;
import java.util.TreeMap;


public class BrokerOperationsImpl extends HasMetadataOperation<Broker, BrokerList, Resource<Broker>> {

  public BrokerOperationsImpl(OkHttpClient client, Config config) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public BrokerOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("eventing.knative.dev")
    .withApiGroupVersion("v1")
    .withPlural("brokers"));
    this.type = Broker.class;
    this.listType = BrokerList.class;
  }

  public BrokerOperationsImpl newInstance(OperationContext context) {
    return new BrokerOperationsImpl(context);
  }

  @Override
  public Broker edit(Visitor... visitors) {
    return patch(new BrokerBuilder(getMandatory()).accept(visitors).build());
  }
 
  @Override
  public boolean isResourceNamespaced() {
    return true;
  }
}
